@@ -2,6 +2,7 @@ import requests, os, sys
 import hashlib
 import smtplib, ssl
 import random, string, uuid
+import base64
 class login:
     k=str(uuid.getnode())
     ke=k.encode('utf-8')
@@ -52,7 +53,7 @@ class login:
             print('Invalid Username Password Or Mail!')
             sys.exit()
 class verify:
-    def verify(auth_id, mail, subject, mail_text):
+    def verify(mail, subject, mail_text):
         global code
         login=requests.get('https://pastebin.com/'+auth_id)
         email=mail.encode('utf-8')
